﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Text;
using System.Xml;
using Newtonsoft.Json;
namespace ConsoleApplication2
{
    class Program
    {
        static void Main(string[] args)
        {
            var xml = File.ReadAllText(@".\cnblogs.xml");//该xml为博客园随笔备份文件
            //var xml = File.ReadAllText(@".\cnSingle.xml");//该xml为博客园随笔备份文件
            XmlDocument doc = new XmlDocument();
            doc.LoadXml(xml);
            //获取rss节点下的内容
            var channelXml = doc.SelectSingleNode("rss").InnerXml;
            //进一步细化xml格式，内容仅为rss节点下的内容
            doc.LoadXml(channelXml);
            //判断item对象个数
            var items = doc.SelectNodes("channel/item");
            if (items.Count == 1)//仅当随笔内容有1项时才会多此一举
            {
                //1.如果仅有一个item,序列化后的json格式为 "item": {"title": "测试","link":"",....} 这样的json格式并不能序列化成List<item>的
                //刻意去添加一个空节点 在序列化成json的格式为 "item":[{"title": "测试"...},{}...] 这样就可以序列化成List<item>了
                var item = doc.CreateElement("item");
                doc.FirstChild.AppendChild(item);
            }
            //将xml序列化成json，并且去掉根节点
            var json = JsonConvert.SerializeXmlNode(doc, Newtonsoft.Json.Formatting.Indented, true);
            var channel = JsonConvert.DeserializeObject<Channel>(json); 
            //打印读取的内容
            Console.WriteLine("title:{0}", channel.title);
            Console.WriteLine("link:{0}", channel.link);
            Console.WriteLine("description:{0}", channel.description);
            Console.WriteLine("language:{0}", channel.language);
            Console.WriteLine("lastBuildDate:{0}", channel.lastBuildDate);
            Console.WriteLine("pubDate:{0}", channel.pubDate);
            Console.WriteLine("ttl:{0}", channel.ttl);
            foreach (var sigleItem in channel.items)
            {
                if (sigleItem == null) continue;
                Console.WriteLine();
                Console.WriteLine("title:{0}", sigleItem.title);
                Console.WriteLine("link:{0}", sigleItem.link);
                Console.WriteLine("description:{0}", sigleItem.description);
                Console.WriteLine("pubDate:{0}", sigleItem.pubDate);
                Console.WriteLine("guid:{0}", sigleItem.guid);
                Console.WriteLine("content:{0}", sigleItem.description.content);
            }
            Console.ReadKey();
        }

        #region 结构定义
        public class Channel
        {
            public string title { get; set; }
            public string link { get; set; }
            public string description { get; set; }
            public string language { get; set; }
            public string lastBuildDate { get; set; }
            public string pubDate { get; set; }
            public string ttl { get; set; }
            [JsonProperty("item")]
            public List<Channel_Item> items { get; set; }
        }

        public class Channel_Item
        {
            public string title { get; set; }
            public string link { get; set; }
            public string author { get; set; }
            public string pubDate { get; set; }
            public string guid { get; set; }
            public Item_Description description { get; set; }
        }

        public class Item_Description
        {
            //默认以变量名称作为json序列化的节点，由于该节点内容不符合变量定义规范，则显示指定即可
            [JsonProperty("#cdata-section")]
            public string content { get; set; }
        }
        #endregion
    }
}
